import { MediaConvertClient } from "./MediaConvertClient";
import { AssociateCertificateInput } from "./types/AssociateCertificateInput";
import { AssociateCertificateOutput } from "./types/AssociateCertificateOutput";
import { CancelJobInput } from "./types/CancelJobInput";
import { CancelJobOutput } from "./types/CancelJobOutput";
import { CreateJobInput } from "./types/CreateJobInput";
import { CreateJobOutput } from "./types/CreateJobOutput";
import { CreateJobTemplateInput } from "./types/CreateJobTemplateInput";
import { CreateJobTemplateOutput } from "./types/CreateJobTemplateOutput";
import { CreatePresetInput } from "./types/CreatePresetInput";
import { CreatePresetOutput } from "./types/CreatePresetOutput";
import { CreateQueueInput } from "./types/CreateQueueInput";
import { CreateQueueOutput } from "./types/CreateQueueOutput";
import { DeleteJobTemplateInput } from "./types/DeleteJobTemplateInput";
import { DeleteJobTemplateOutput } from "./types/DeleteJobTemplateOutput";
import { DeletePresetInput } from "./types/DeletePresetInput";
import { DeletePresetOutput } from "./types/DeletePresetOutput";
import { DeleteQueueInput } from "./types/DeleteQueueInput";
import { DeleteQueueOutput } from "./types/DeleteQueueOutput";
import { DescribeEndpointsInput } from "./types/DescribeEndpointsInput";
import { DescribeEndpointsOutput } from "./types/DescribeEndpointsOutput";
import { DisassociateCertificateInput } from "./types/DisassociateCertificateInput";
import { DisassociateCertificateOutput } from "./types/DisassociateCertificateOutput";
import { GetJobInput } from "./types/GetJobInput";
import { GetJobOutput } from "./types/GetJobOutput";
import { GetJobTemplateInput } from "./types/GetJobTemplateInput";
import { GetJobTemplateOutput } from "./types/GetJobTemplateOutput";
import { GetPresetInput } from "./types/GetPresetInput";
import { GetPresetOutput } from "./types/GetPresetOutput";
import { GetQueueInput } from "./types/GetQueueInput";
import { GetQueueOutput } from "./types/GetQueueOutput";
import { ListJobTemplatesInput } from "./types/ListJobTemplatesInput";
import { ListJobTemplatesOutput } from "./types/ListJobTemplatesOutput";
import { ListJobsInput } from "./types/ListJobsInput";
import { ListJobsOutput } from "./types/ListJobsOutput";
import { ListPresetsInput } from "./types/ListPresetsInput";
import { ListPresetsOutput } from "./types/ListPresetsOutput";
import { ListQueuesInput } from "./types/ListQueuesInput";
import { ListQueuesOutput } from "./types/ListQueuesOutput";
import { ListTagsForResourceInput } from "./types/ListTagsForResourceInput";
import { ListTagsForResourceOutput } from "./types/ListTagsForResourceOutput";
import { TagResourceInput } from "./types/TagResourceInput";
import { TagResourceOutput } from "./types/TagResourceOutput";
import { UntagResourceInput } from "./types/UntagResourceInput";
import { UntagResourceOutput } from "./types/UntagResourceOutput";
import { UpdateJobTemplateInput } from "./types/UpdateJobTemplateInput";
import { UpdateJobTemplateOutput } from "./types/UpdateJobTemplateOutput";
import { UpdatePresetInput } from "./types/UpdatePresetInput";
import { UpdatePresetOutput } from "./types/UpdatePresetOutput";
import { UpdateQueueInput } from "./types/UpdateQueueInput";
import { UpdateQueueOutput } from "./types/UpdateQueueOutput";
export declare class MediaConvert extends MediaConvertClient {
    /**
     * Associates an AWS Certificate Manager (ACM) Amazon Resource Name (ARN) with AWS Elemental MediaConvert.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    associateCertificate(args: AssociateCertificateInput): Promise<AssociateCertificateOutput>;
    associateCertificate(args: AssociateCertificateInput, cb: (err: any, data?: AssociateCertificateOutput) => void): void;
    /**
     * Permanently cancel a job. Once you have canceled a job, you can't start it again.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    cancelJob(args: CancelJobInput): Promise<CancelJobOutput>;
    cancelJob(args: CancelJobInput, cb: (err: any, data?: CancelJobOutput) => void): void;
    /**
     * Create a new transcoding job. For information about jobs and job settings, see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createJob(args: CreateJobInput): Promise<CreateJobOutput>;
    createJob(args: CreateJobInput, cb: (err: any, data?: CreateJobOutput) => void): void;
    /**
     * Create a new job template. For information about job templates see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createJobTemplate(args: CreateJobTemplateInput): Promise<CreateJobTemplateOutput>;
    createJobTemplate(args: CreateJobTemplateInput, cb: (err: any, data?: CreateJobTemplateOutput) => void): void;
    /**
     * Create a new preset. For information about job templates see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createPreset(args: CreatePresetInput): Promise<CreatePresetOutput>;
    createPreset(args: CreatePresetInput, cb: (err: any, data?: CreatePresetOutput) => void): void;
    /**
     * Create a new transcoding queue. For information about queues, see Working With Queues in the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/working-with-queues.html
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createQueue(args: CreateQueueInput): Promise<CreateQueueOutput>;
    createQueue(args: CreateQueueInput, cb: (err: any, data?: CreateQueueOutput) => void): void;
    /**
     * Permanently delete a job template you have created.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteJobTemplate(args: DeleteJobTemplateInput): Promise<DeleteJobTemplateOutput>;
    deleteJobTemplate(args: DeleteJobTemplateInput, cb: (err: any, data?: DeleteJobTemplateOutput) => void): void;
    /**
     * Permanently delete a preset you have created.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deletePreset(args: DeletePresetInput): Promise<DeletePresetOutput>;
    deletePreset(args: DeletePresetInput, cb: (err: any, data?: DeletePresetOutput) => void): void;
    /**
     * Permanently delete a queue you have created.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteQueue(args: DeleteQueueInput): Promise<DeleteQueueOutput>;
    deleteQueue(args: DeleteQueueInput, cb: (err: any, data?: DeleteQueueOutput) => void): void;
    /**
     * Send an request with an empty body to the regional API endpoint to get your account API endpoint.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeEndpoints(args: DescribeEndpointsInput): Promise<DescribeEndpointsOutput>;
    describeEndpoints(args: DescribeEndpointsInput, cb: (err: any, data?: DescribeEndpointsOutput) => void): void;
    /**
     * Removes an association between the Amazon Resource Name (ARN) of an AWS Certificate Manager (ACM) certificate and an AWS Elemental MediaConvert resource.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    disassociateCertificate(args: DisassociateCertificateInput): Promise<DisassociateCertificateOutput>;
    disassociateCertificate(args: DisassociateCertificateInput, cb: (err: any, data?: DisassociateCertificateOutput) => void): void;
    /**
     * Retrieve the JSON for a specific completed transcoding job.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getJob(args: GetJobInput): Promise<GetJobOutput>;
    getJob(args: GetJobInput, cb: (err: any, data?: GetJobOutput) => void): void;
    /**
     * Retrieve the JSON for a specific job template.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getJobTemplate(args: GetJobTemplateInput): Promise<GetJobTemplateOutput>;
    getJobTemplate(args: GetJobTemplateInput, cb: (err: any, data?: GetJobTemplateOutput) => void): void;
    /**
     * Retrieve the JSON for a specific preset.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getPreset(args: GetPresetInput): Promise<GetPresetOutput>;
    getPreset(args: GetPresetInput, cb: (err: any, data?: GetPresetOutput) => void): void;
    /**
     * Retrieve the JSON for a specific queue.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getQueue(args: GetQueueInput): Promise<GetQueueOutput>;
    getQueue(args: GetQueueInput, cb: (err: any, data?: GetQueueOutput) => void): void;
    /**
     * Retrieve a JSON array of up to twenty of your job templates. This will return the templates themselves, not just a list of them. To retrieve the next twenty templates, use the nextToken string returned with the array
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listJobTemplates(args: ListJobTemplatesInput): Promise<ListJobTemplatesOutput>;
    listJobTemplates(args: ListJobTemplatesInput, cb: (err: any, data?: ListJobTemplatesOutput) => void): void;
    /**
     * Retrieve a JSON array of up to twenty of your most recently created jobs. This array includes in-process, completed, and errored jobs. This will return the jobs themselves, not just a list of the jobs. To retrieve the twenty next most recent jobs, use the nextToken string returned with the array.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listJobs(args: ListJobsInput): Promise<ListJobsOutput>;
    listJobs(args: ListJobsInput, cb: (err: any, data?: ListJobsOutput) => void): void;
    /**
     * Retrieve a JSON array of up to twenty of your presets. This will return the presets themselves, not just a list of them. To retrieve the next twenty presets, use the nextToken string returned with the array.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listPresets(args: ListPresetsInput): Promise<ListPresetsOutput>;
    listPresets(args: ListPresetsInput, cb: (err: any, data?: ListPresetsOutput) => void): void;
    /**
     * Retrieve a JSON array of up to twenty of your queues. This will return the queues themselves, not just a list of them. To retrieve the next twenty queues, use the nextToken string returned with the array.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listQueues(args: ListQueuesInput): Promise<ListQueuesOutput>;
    listQueues(args: ListQueuesInput, cb: (err: any, data?: ListQueuesOutput) => void): void;
    /**
     * Retrieve the tags for a MediaConvert resource.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listTagsForResource(args: ListTagsForResourceInput): Promise<ListTagsForResourceOutput>;
    listTagsForResource(args: ListTagsForResourceInput, cb: (err: any, data?: ListTagsForResourceOutput) => void): void;
    /**
     * Add tags to a MediaConvert queue, preset, or job template. For information about tagging, see the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-resources.html
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    tagResource(args: TagResourceInput): Promise<TagResourceOutput>;
    tagResource(args: TagResourceInput, cb: (err: any, data?: TagResourceOutput) => void): void;
    /**
     * Remove tags from a MediaConvert queue, preset, or job template. For information about tagging, see the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-resources.html
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    untagResource(args: UntagResourceInput): Promise<UntagResourceOutput>;
    untagResource(args: UntagResourceInput, cb: (err: any, data?: UntagResourceOutput) => void): void;
    /**
     * Modify one of your existing job templates.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateJobTemplate(args: UpdateJobTemplateInput): Promise<UpdateJobTemplateOutput>;
    updateJobTemplate(args: UpdateJobTemplateInput, cb: (err: any, data?: UpdateJobTemplateOutput) => void): void;
    /**
     * Modify one of your existing presets.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updatePreset(args: UpdatePresetInput): Promise<UpdatePresetOutput>;
    updatePreset(args: UpdatePresetInput, cb: (err: any, data?: UpdatePresetOutput) => void): void;
    /**
     * Modify one of your existing queues.
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} The service can't process your request because of a problem in the request. Please check your request form and syntax.
     *   - {InternalServerErrorException} The service encountered an unexpected condition and can't fulfill your request.
     *   - {ForbiddenException} You don't have permissions for this action with the credentials you sent.
     *   - {NotFoundException} The resource you requested doesn't exist.
     *   - {TooManyRequestsException} Too many requests have been sent in too short of a time. The service limits the rate at which it will accept requests.
     *   - {ConflictException} The service couldn't complete your request because there is a conflict with the current state of the resource.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateQueue(args: UpdateQueueInput): Promise<UpdateQueueOutput>;
    updateQueue(args: UpdateQueueInput, cb: (err: any, data?: UpdateQueueOutput) => void): void;
}
